@@ -4,17 +4,13 @@ import torch.nn as nn
 import torch.nn.functional as F
 from tqdm import tqdm
 from torch.autograd import Variable
-
-from DeepMatter.viz.format import layout_fig
+from .Auto_format import *
 
 
 class conv2D_Res_block(nn.Module):
-    """
-    Class that builds a two dimensional convolutional layer with a residual block
-    """
 
     def __init__(self, t_size, n_step):
-        """
+        """  Class that builds a two dimensional convolutional layer with a residual block
 
         Args:
             self:
